fetch('http://localhost:4000/api/blog/posts')
    .then(response => response.json())
    .then(res => {
        const posts = res.data;
        const container = document.getElementById('blog-posts-container');

        // Check if there are no posts
        if (posts.length === 0) {
            container.innerHTML = '<p>No blog posts available.</p>';
            return;
        }

        // Start building the posts grid
        let htmlContent = '<div class="owl-carousel owl-carousel-style-2" data-items="1" data-sm-items="2" data-md-items="3" data-stage-padding="30" data-lg-stage-padding="100" data-loop="true" data-margin="30" data-mouse-drag="true">';

        // Append articles to the grid
        posts.forEach(post => {
            htmlContent += `
            <article class="post-preview post-preview-center"> <img class="img-responsive" src="${post.image}" alt="${post.title}" width="222" height="232">
                <div class="caption">
                <p class="post-preview-title"> <a href="/blog/${post.slug}">${post.title}</a> </p>
                <p class="post-card-excerpt">${post.description.slice(0, 100)}...</p>
                <ul class="post-meta"><time datetime="${post.created_at}">${new Date(post.created_at).toLocaleDateString()}</time>
                <a href="/blog/${post.category.slug}" class="post-card-category">${post.category.name}</a>
                </ul>
                </div>
            </article>
            `;
        });

        // Close the posts grid
        htmlContent += '</div>';

        // Set the HTML of the container
        container.innerHTML = htmlContent;
    
        // Reinitialize the Owl Carousel
        $('.owl-carousel').owlCarousel({
            items: 1,
            stagePadding: 30,
            loop: true,
            margin: 30,
            mouseDrag: true,
            responsive: {
                0: {
                    items: 1,
                    stagePadding: 10,
                    margin: 10
                },
                768: {
                    items: 2,
                    stagePadding: 20,
                    margin: 20
                },
                992: {
                    items: 3,
                    stagePadding: 100,
                    margin: 30
                }
            }
        });
    })
    .catch(error => console.error('Error fetching blog posts:', error));
