import type { ForexTransaction } from '~~/types'
export const useForexTransactionStore = defineStore({
  id: 'forexTransaction',

  // State
  state: () => ({
    transactions: [] as ForexTransaction[],
    loading: false,
    selectedTransaction: null as ForexTransaction | null,
  }),

  // Getters
  getters: {
    getTransactionById: (state) => (id: number) =>
      state.transactions.find((transaction) => transaction.id === id),
  },

  // Actions
  actions: {
    async fetchForexTransactions() {
      this.loading = true
      try {
        const { getUserForexTransactions } = useForex()
        const response = await getUserForexTransactions()
        this.transactions = response.data
      } catch (error) {
        console.error('Error fetching deposit transactions:', error)
      }
      this.loading = false
    },
    async removeTransaction(id: number) {
      const index = this.transactions.findIndex((m) => m.id === id)
      this.transactions.splice(index, 1)
    },
    async selectTransaction(transaction: ForexTransaction) {
      this.selectedTransaction = transaction
    },
    async selectTransactionById(id: number) {
      this.selectedTransaction =
        this.transactions.find((m) => m.id === id) || null
    },
  },
})
